@@ -13,6 +13,7 @@ from poetry.core.version.markers import parse_marker
 from poetry.factory import Factory
 from poetry.packages import Locker as BaseLocker
 from poetry.repositories.legacy_repository import LegacyRepository
+from poetry.repositories.repository_pool import Priority
 
 from poetry_plugin_export.exporter import Exporter
 from tests.markers import MARKER_CPYTHON
@@ -1807,7 +1808,7 @@ def test_exporter_exports_requirements_txt_with_default_and_secondary_sources(
             "https://b.example.com/simple",
             config=poetry.config,
         ),
-        default=True,
+        priority=Priority.DEFAULT,
     )
     poetry.pool.add_repository(
         LegacyRepository(
@@ -1815,7 +1816,7 @@ def test_exporter_exports_requirements_txt_with_default_and_secondary_sources(
             "https://a.example.com/simple",
             config=poetry.config,
         ),
-        secondary=True,
+        priority=Priority.SECONDARY,
     )
     poetry.locker.mock_lock_data(  # type: ignore[attr-defined]
         {
@@ -2099,16 +2100,6 @@ def test_exporter_doesnt_confuse_repeated_packages(
     io = BufferedIO()
     exporter.export("requirements.txt", tmp_path, io)
 
-    expected_legacy = f"""\
-celery==5.1.2 ; {MARKER_PY36_ONLY}
-celery==5.2.3 ; {MARKER_PY37}
-click-didyoumean==0.0.3 ; {MARKER_PY36_PY362}
-click-didyoumean==0.3.0 ; {MARKER_PY362_PY40}
-click-plugins==1.1.1 ; {MARKER_PY36}
-click==7.1.2 ; python_version < "3.7" and python_version >= "3.6"
-click==8.0.3 ; {MARKER_PY37}
-"""
-
     expected = f"""\
 celery==5.1.2 ; {MARKER_PY36_ONLY}
 celery==5.2.3 ; {MARKER_PY37}
@@ -2119,7 +2110,7 @@ click==7.1.2 ; {MARKER_PY36_ONLY}
 click==8.0.3 ; {MARKER_PY37}
 """
 
-    assert io.fetch_output() in {expected, expected_legacy}
+    assert io.fetch_output() == expected
 
 
 def test_exporter_handles_extras_next_to_non_extras(
@@ -2672,3 +2663,60 @@ def test_exporter_tolerates_non_existent_extra(tmp_path: Path, poetry: Poetry) -
 foo[baz]==1.2.3 ; {MARKER_PY27} or {MARKER_PY36}
 """
     assert content == expected
+
+
+def test_exporter_exports_extra_index_url_and_trusted_host(
+    tmp_path: Path, poetry: Poetry
+) -> None:
+    poetry.pool.add_repository(
+        LegacyRepository(
+            "custom",
+            "http://example.com/simple",
+        ),
+        priority=Priority.EXPLICIT,
+    )
+    poetry.locker.mock_lock_data(  # type: ignore[attr-defined]
+        {
+            "package": [
+                {
+                    "name": "foo",
+                    "version": "1.2.3",
+                    "optional": False,
+                    "python-versions": "*",
+                    "dependencies": {"bar": "*"},
+                },
+                {
+                    "name": "bar",
+                    "version": "4.5.6",
+                    "optional": False,
+                    "python-versions": "*",
+                    "source": {
+                        "type": "legacy",
+                        "url": "http://example.com/simple",
+                        "reference": "",
+                    },
+                },
+            ],
+            "metadata": {
+                "python-versions": "*",
+                "content-hash": "123456789",
+                "files": {"foo": [], "bar": []},
+            },
+        }
+    )
+    set_package_requires(poetry)
+
+    exporter = Exporter(poetry, NullIO())
+    exporter.export("requirements.txt", tmp_path, "requirements.txt")
+
+    with (tmp_path / "requirements.txt").open(encoding="utf-8") as f:
+        content = f.read()
+
+    expected = f"""\
+--trusted-host example.com
+--extra-index-url http://example.com/simple
+
+bar==4.5.6 ; {MARKER_PY}
+foo==1.2.3 ; {MARKER_PY}
+"""
+    assert content == expected
