@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 from typing import TYPE_CHECKING
-from typing import Protocol  # noqa: TYP001
+from typing import Protocol
 
 
 if TYPE_CHECKING:
